===================
acdh-handle-pyutils
===================

.. image:: https://github.com/csae8092/acdh-handle-pyutils/workflows/Build%20acdh-handle-pyutils%20Package/badge.svg
        :target: https://github.com/csae8092/acdh-handle-pyutils/workflows/Build%20acdh-handle-pyutils%20Package/badge.svg
        :alt: Github Workflow Build acdh-handle-pyutils Status

.. image:: https://github.com/csae8092/acdh-handle-pyutils/workflows/Run%20acdh-handle-pyutils%20Tox%20Test%20Suite/badge.svg
        :target: https://github.com/csae8092/acdh-handle-pyutils/workflows/Run%20acdh-handle-pyutils%20Tox%20Test%20Suite/badge.svg
        :alt: Github Workflow Tests Status

.. image:: https://img.shields.io/pypi/v/acdh-handle-pyutils.svg
        :target: https://pypi.python.org/pypi/acdh-handle-pyutils
        :alt: PyPI Status


.. image:: https://readthedocs.org/projects/acdh-handle-pyutils/badge/?version=latest
        :target: https://acdh-handle-pyutils.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :target: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :alt: Dependabot Enabled


Utility functions to interact with handle.net API


* Free software: MIT
* Documentation: https://acdh-handle-pyutils.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with cookietemple_ using Cookiecutter_.

.. _cookietemple: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
